@@ -1,4 +1,4 @@
-/* FvwmBacker Module for Fvwm.
+/* FvwmBacker Module for Fvwm. 
  *
  *  Copyright 1994,  Mike Finger (mfinger@mermaid.micro.umn.edu or
  *                               Mike_Finger@atk.com)
@@ -18,30 +18,14 @@
  * own risk. Permission to use this program for any purpose is given,
  * as long as the copyright is kept intact. */
 
-/* This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
-
-#include "libs/fvwmlib.h"
+#include <fvwm/fvwmlib.h>     
 
 /* Function Prototypes */
 
 void EndLessLoop();
 void ReadFvwmPipe();
-void ProcessMessage(unsigned long type, unsigned long *body);
+void ProcessMessage(unsigned long type,unsigned long *body);
+void SendFvwmPipe(char *message,unsigned long window);
 void DeadPipe(int nonsense);
 void ParseConfig(void);
-int ParseConfigLine(char *line);
-void AddCommand(char *line);
+void AddCommand(char *string);
