@@ -1,56 +1,44 @@
-/* This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
 /*************************************************************************
  *
  * Subroutine Prototypes
- *
+ * 
  *************************************************************************/
-#include "libs/fvwmlib.h"
-#include <libs/vpacket.h>
-#include "libs/Flocale.h"
+#include <fvwm/fvwmlib.h>
 
 struct icon_info;
-void MySendFvwmPipe(int *fd, char *message, unsigned long window);
 Bool ExecIconBoxFunction(char *msg);
 extern void   CreateWindow(void);
 extern Pixel  GetColor(char *name);
 extern Pixel  GetHilite(Pixel background);
 extern Pixel  GetShadow(Pixel background);
 extern void   nocolor(char *a, char *b);
-extern void   RedrawWindow(XEvent *evp);
+extern void   RedrawWindow(void);
 extern void   match_string(char *tline);
 extern void   Loop(void);
 extern void   ParseOptions(void);
 extern char   *safemalloc(int length);
+extern void   change_window_name(char *str);
 extern int    My_XNextEvent(Display *dpy, XEvent *event);
+extern void   CopyString(char **dest, char *source);
+extern inline void RelieveWindow(Window win,int x,int y,int w,int h,GC rGC,GC sGC); 
+extern void   SendFvwmPipe(int *,char *text, unsigned long window);
 extern void   DeadPipe(int nonsense);
 extern void   CreateIconWindow(struct icon_info *item);
+extern void   ConfigureIconWindow(struct icon_info *item);
 extern void   DrawIconWindow(struct icon_info *item);
-extern void   GetIconFromFile(struct icon_info *item);
+extern void   GetBitmapFile(struct icon_info *item);
+extern void   GetXPMFile(struct icon_info *item);
 extern void GetIconWindow(struct icon_info *item);
 extern void GetIconBitmap(struct icon_info *item);
 extern void process_message(unsigned long type,unsigned long *body);
-/* extern Bool AddItem(unsigned long id, long desk, unsigned long flags); */
-extern Bool AddItem(ConfigWinPacket *cfgpacket);
+extern void send_clientmessage (Window w, Atom a, Time timestamp);
+extern Bool AddItem(unsigned long id, long desk, unsigned long flags);
 extern Bool DeleteItem(unsigned long id);
 extern struct icon_info *UpdateItem(unsigned long type, unsigned long id, char *item);
 extern void freeitem(struct icon_info *item, int d);
 extern void RedrawHScrollbar(void);
 extern void RedrawVScrollbar(void);
-extern void RedrawIcons(XEvent *evp);
+extern void RedrawIcons(void);
 extern void GetIconwinSize(int *dx, int *dy);
 extern void RedrawLeftButton(GC rgc, GC sgc);
 extern void RedrawRightButton(GC rgc, GC sgc);
@@ -66,8 +54,8 @@ extern void parseaction(char *tline);
 extern void AdjustIconWindow(struct icon_info *item, int n);
 extern int AdjustIconWindows(void);
 extern struct icon_info *SetFlag(unsigned long id, int t);
-extern void RedrawIcon(struct icon_info *item, int f, XEvent *evp);
-extern void animate(struct icon_info *item, unsigned long *body);
+extern void sleep_a_little(int n);
+extern void RedrawIcon(struct icon_info *item, int f);
 extern void Next(void);
 extern void Prev(void);
 extern void GetDefaultPixmap(struct icon_info *item);
@@ -80,23 +68,25 @@ extern void ExecuteKey(XEvent event);
 extern int matchWildcards(char *pattern, char *string);
 extern Bool GetBackPixmap(void);
 extern int LookInList(struct icon_info *item);
-extern char *stripcpy2(char *source);
+extern char *stripcpy(char *source);
 extern void mapicons(void);
-extern int window_cond(struct icon_info *item);
+extern int desk_cond(struct icon_info *item);
 extern int itemcmp(struct icon_info *item1, struct icon_info *item2);
+extern XErrorHandler myErrorHandler(Display *dpy, XErrorEvent *event);
 
 
-extern Display *dpy;                    /* which display are we talking to */
+extern Display *dpy;			/* which display are we talking to */
 extern Window Root;
 extern Window main_win;
 extern Window holder_win;
 extern Window icon_win;
 extern int screen;
+extern int d_depth;
 extern Pixel fore_pix, back_pix, icon_fore_pix, icon_back_pix;
 extern GC  NormalGC;
 extern GC  ReliefGC;
-extern FlocaleFont *Ffont;
 extern int ButtonWidth,ButtonHeight;
+extern XFontStruct *font;
 extern int num_rows;
 extern int num_columns;
 extern int Lines;
@@ -110,32 +100,28 @@ extern char *IconwinPixmapFile;
 
 struct icon_info
 {
-	char *action;
-	char *name;
-	char *window_name;
-	char *res_class;
-	char *res_name;
-	char *icon_file;
-	int x;
-	int y;
-	int icon_w;
-	int icon_h;
-	Pixmap iconPixmap;            /* pixmap for the icon */
-	Pixmap icon_maskPixmap;
-	Pixmap icon_alphaPixmap;
-	int icon_depth;
-	int icon_nalloc_pixels;
-	Pixel *icon_alloc_pixels;
-	int icon_no_limit;
-	Window IconWin;
-	Window icon_pixmap_w;
-	XWMHints *wmhints;
-	long id;
-	long desk;
-	window_flags flags;
-	long extra_flags;
-	struct icon_info *next;
-	struct icon_info *prev;
+  char *action;
+  char *name;
+  char *window_name;
+  char *res_class;
+  char *res_name;
+  char *icon_file;
+  int x;
+  int y;
+  int icon_w;
+  int icon_h;
+  Pixmap iconPixmap;		/* pixmap for the icon */
+  Pixmap icon_maskPixmap;	
+  Window IconWin;
+  Window icon_pixmap_w;
+  XWMHints *wmhints;
+  int icon_depth;
+  long id;
+  long desk;
+  long flags;
+  long extra_flags;
+  struct icon_info *next;
+  struct icon_info *prev;
 };
 
 struct iconfile
@@ -156,7 +142,7 @@ struct mousefunc
 struct keyfunc
 {
   char *name;
-  KeyCode keycode;
+  KeyCode keycode;           
   char *action;
   struct keyfunc *next;
 };
@@ -167,10 +153,18 @@ extern struct func *Actions;
 extern struct iconfile *IconListHead;
 extern struct iconfile *IconListTail;
 
-extern char *imagePath;
+extern char *iconPath;
+extern char *pixmapPath;
 
 extern int icon_relief;
 
+#ifdef BROKEN_SUN_HEADERS
+#include "../../fvwm/sun_headers.h"
+#endif
+
+#ifdef NEEDS_ALPHA_HEADER
+#include "../../fvwm/alpha_header.h"
+#endif /* NEEDS_ALPHA_HEADER */
 
 
 #define NOPLACE -1
@@ -179,13 +173,12 @@ extern int icon_relief;
 #define TOP 2
 #define BOTTOM 3
 
-#include "fvwm/fvwm.h"
+#include "../../fvwm/fvwm.h"
 
 #define NO_CLICK 0
 #define CLICK 1
 #define ONE_AND_A_HALF_CLICKS 3
 #define DOUBLE_CLICK 2
-#define TIMEOUT 3
 
 /* sorting */
 #define UNSORT     0
@@ -194,6 +187,11 @@ extern int icon_relief;
 #define RESNAME    3
 #define RESCLASS   4
 
+#ifndef min
+#define min(a,b) (((a)<(b)) ? (a) : (b))
+#define max(a,b) (((a)>(b)) ? (a) : (b))
+#endif
+
 /* local flags */
 #define HIDE_H        (1<<0)
 #define HIDE_V        (1<<1)
