@@ -1,18 +1,3 @@
-/* This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
 #include "Tools.h"
 
 extern int fd[2];
@@ -25,10 +10,10 @@ void DrawRelief(struct XObj *xobj)
 {
  XSegment segm[2];
  int i;
-
+ 
  if (xobj->value!=0)
  {
-  for (i=1;i<2;i++)
+  for (i=1;i<4;i++)
   {
    segm[0].x1=xobj->x-i;
    segm[0].y1=xobj->y-i;
@@ -39,11 +24,11 @@ void DrawRelief(struct XObj *xobj)
    segm[1].x2=xobj->x-i;
    segm[1].y2=xobj->y+xobj->height+i-2;
    if (xobj->value==-1)
-    XSetForeground(dpy,xobj->gc,xobj->TabColor[shad]);
+    XSetForeground(xobj->display,xobj->gc,xobj->TabColor[shad].pixel);
    else
-    XSetForeground(dpy,xobj->gc,xobj->TabColor[hili]);
-   XDrawSegments(dpy,x11base->win,xobj->gc,segm,2);
-
+    XSetForeground(xobj->display,xobj->gc,xobj->TabColor[li].pixel);
+   XDrawSegments(xobj->display,*xobj->ParentWin,xobj->gc,segm,2);
+ 
    segm[0].x1=xobj->x-i;
    segm[0].y1=xobj->y+xobj->height+i-1;
    segm[0].x2=xobj->x+xobj->width+i-1;
@@ -53,10 +38,10 @@ void DrawRelief(struct XObj *xobj)
    segm[1].x2=xobj->x+xobj->width+i-1;
    segm[1].y2=xobj->y+xobj->height+i-1;
    if (xobj->value==-1)
-    XSetForeground(dpy,xobj->gc,xobj->TabColor[hili]);
+    XSetForeground(xobj->display,xobj->gc,xobj->TabColor[li].pixel);
    else
-    XSetForeground(dpy,xobj->gc,xobj->TabColor[shad]);
-   XDrawSegments(dpy,x11base->win,xobj->gc,segm,2);
+    XSetForeground(xobj->display,xobj->gc,xobj->TabColor[shad].pixel);
+   XDrawSegments(xobj->display,*xobj->ParentWin,xobj->gc,segm,2);
   }
  }
 
@@ -68,20 +53,15 @@ void InitSwallow(struct XObj *xobj)
  XSetWindowAttributes Attr;
 
  /* Enregistrement des couleurs et de la police */
- if (xobj->colorset >= 0) {
-  xobj->TabColor[fore] = Colorset[xobj->colorset].fg;
-  xobj->TabColor[back] = Colorset[xobj->colorset].bg;
-  xobj->TabColor[hili] = Colorset[xobj->colorset].hilite;
-  xobj->TabColor[shad] = Colorset[xobj->colorset].shadow;
- } else {
-  xobj->TabColor[fore] = GetColor(xobj->forecolor);
-  xobj->TabColor[back] = GetColor(xobj->backcolor);
-  xobj->TabColor[hili] = GetColor(xobj->hilicolor);
-  xobj->TabColor[shad] = GetColor(xobj->shadcolor);
- }
+ MyAllocNamedColor(xobj->display,*xobj->colormap,xobj->forecolor,&xobj->TabColor[fore]); 
+ MyAllocNamedColor(xobj->display,*xobj->colormap,xobj->backcolor,&xobj->TabColor[back]);
+ MyAllocNamedColor(xobj->display,*xobj->colormap,xobj->licolor,&xobj->TabColor[li]); 
+ MyAllocNamedColor(xobj->display,*xobj->colormap,xobj->shadcolor,&xobj->TabColor[shad]);
+ MyAllocNamedColor(xobj->display,*xobj->colormap,"#000000",&xobj->TabColor[black]);
+ MyAllocNamedColor(xobj->display,*xobj->colormap,"#FFFFFF",&xobj->TabColor[white]);
 
  mask=0;
- xobj->win=XCreateWindow(dpy,*xobj->ParentWin,
+ xobj->win=XCreateWindow(xobj->display,*xobj->ParentWin,
 		-1000,-1000,xobj->width,xobj->height,0,
 		CopyFromParent,InputOutput,CopyFromParent,
 		mask,&Attr);
@@ -89,7 +69,7 @@ void InitSwallow(struct XObj *xobj)
  /* Redimensionnement du widget */
  if (xobj->height<30)
   xobj->height=30;
- if (xobj->width<30)
+ if (xobj->width<30) 
   xobj->width=30;
 
  if (xobj->swallow!=NULL)
@@ -103,9 +83,10 @@ void InitSwallow(struct XObj *xobj)
 
 void DestroySwallow(struct XObj *xobj)
 {
+ XSetCloseDownMode(xobj->display,DestroyAll);
  /* Arrete le programme swallow */
  if (xobj->win!=None)
-  XKillClient(dpy, xobj->win);
+  XKillClient(xobj->display, xobj->win);
 }
 
 void DrawSwallow(struct XObj *xobj)
@@ -134,8 +115,8 @@ void CheckForHangon(struct XObj *xobj,unsigned long *body)
    free(xobj->title);
    xobj->title=(char*)calloc(sizeof(char),20);
    sprintf(xobj->title,"No window");
-   XUnmapWindow(dpy,xobj->win);
-   XSetWindowBorderWidth(dpy,xobj->win,0);
+   XUnmapWindow(xobj->display,xobj->win);
+   XSetWindowBorderWidth(xobj->display,xobj->win,0);
   }
   free(cbody);
 }
@@ -145,9 +126,9 @@ void swallow(struct XObj *xobj,unsigned long *body)
 
  if(xobj->win == (Window)body[0])
  {
-  XReparentWindow(dpy,xobj->win,*xobj->ParentWin,xobj->x,xobj->y);
-  XResizeWindow(dpy,xobj->win,xobj->width,xobj->height);
-  XMapWindow(dpy,xobj->win);
+  XReparentWindow(xobj->display,xobj->win,*xobj->ParentWin,xobj->x,xobj->y);
+  XResizeWindow(xobj->display,xobj->win,xobj->width,xobj->height);
+  XMapWindow(xobj->display,xobj->win);
  }
 }
 
@@ -157,9 +138,21 @@ void ProcessMsgSwallow(struct XObj *xobj,unsigned long type,unsigned long *body)
  {
   case M_MAP:
    swallow(xobj,body);
-   break;
+  break;
+  case M_RES_NAME:
+  break;
+  case M_RES_CLASS:
+  break;
   case M_WINDOW_NAME:
-   CheckForHangon(xobj,body);
-   break;
+    CheckForHangon(xobj,body);
+  break;
+  default:
+  break;
  }
 }
+
+
+
+
+
+
