@@ -1,43 +1,33 @@
-/* FvwmTaskBar Module for Fvwm.
+/* FvwmTaskBar Module for Fvwm. 
  *
  *  Copyright 1994,  Mike Finger (mfinger@mermaid.micro.umn.edu or
  *                               Mike_Finger@atk.com)
  *
  * The functions in this source file are the original work of Mike Finger.
- *
+ * 
  * No guarantees or warantees or anything are provided or implied in any way
  * whatsoever. Use this program at your own risk. Permission to use this
  * program for any purpose is given, as long as the copyright is kept intact.
  *
+ *  Things to do:  Convert to C++  (In Progress)
  */
 
-/* This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
-#include "config.h"
-#include "libs/Module.h"
-#include "libs/safemalloc.h"
-
+#include <FVWMconfig.h>
 #include <stdio.h>
 #include <stdlib.h>
-
-#include "FvwmTaskBar.h"
 #include "List.h"
 #include "Mallocs.h"
+#include "../../fvwm/module.h"
+
+
+#ifdef BROKEN_SUN_HEADERS
+#include "../../fvwm/sun_headers.h"
+#endif
+
+#ifdef NEEDS_ALPHA_HEADER
+#include "../../fvwm/alpha_header.h"
+#endif /* NEEDS_ALPHA_HEADER */
 
-extern char *Module;
 
 /******************************************************************************
   InitList - Initialize the list
@@ -51,18 +41,17 @@ void InitList(List *list)
 /******************************************************************************
   AddItem - Allocates spaces for and appends an item to the list
 ******************************************************************************/
-void AddItem(List *list, long id, ConfigWinPacket *cfgpacket,
-             long Desk, int count)
+void AddItem(List *list, long id, long flags, long Desk, int count)
 {
-  Item *new;
+Item *new;
   new=(Item *)safemalloc(sizeof(Item));
   new->id=id;
   new->name=NULL;
-  memcpy(&new->flags, &cfgpacket->flags, sizeof(new->flags));
+  new->flags=flags;
   new->Desk=Desk;
   new->count=count;
-  memset((void *)&(new->p), 0, sizeof(Picture));
   new->next=NULL;
+
   if (list->tail==NULL) list->head=list->tail=new;
   else {
    list->tail->next=new;
@@ -74,21 +63,18 @@ void AddItem(List *list, long id, ConfigWinPacket *cfgpacket,
 /******************************************************************************
   AddItemName - Allocates spaces for and appends an item to the list
 ******************************************************************************/
-void AddItemName(List *list, char *string, int iconified)
-{
+void AddItemName(List *list, char *string, long flags) {
   Item *new;
-
+  
   new = (Item *)safemalloc(sizeof(Item));
   new->id = 0L;
   new->name = NULL;
   UpdateString(&new->name, string);
-  SET_ICONIFIED(new,iconified);
+  new->flags = flags;
   new->next = NULL;
 
-  if (list->tail == NULL)
-    list->head = list->tail = new;
-  else
-  {
+  if (list->tail == NULL) list->head = list->tail = new;
+  else {
     list->tail->next = new;
     list->tail = new;
   }
@@ -101,11 +87,9 @@ void AddItemName(List *list, char *string, int iconified)
 ******************************************************************************/
 int FindItem(List *list, long id)
 {
-  Item *temp;
-
+Item *temp;
   for(temp=list->head;temp!=NULL && temp->id!=id;temp=temp->next);
-  if (temp==NULL)
-    return -1;
+  if (temp==NULL) return -1;
   return temp->count;
 }
 
@@ -124,69 +108,48 @@ int FindNameItem(List *list, char *string)
 }
 
 /******************************************************************************
-  UpdateItem* - Update the item in the list
+  UpdateItem - Update the item in the list, setting name & flags as necessary.
 ******************************************************************************/
-
 int UpdateItemName(List *list, long id, char *string)
 {
-  Item *temp;
+Item *temp;
   for(temp=list->head;temp!=NULL && id!=temp->id;temp=temp->next);
   if (temp==NULL) return -1;
   UpdateString(&temp->name,string);
   return temp->count;
 }
 
-int UpdateItemIconifiedFlag(List *list, long id, int iconified)
+int UpdateItemFlags(List *list, long id, long flags)
 {
-  Item *temp;
+Item *temp;
   for(temp=list->head;temp!=NULL && id!=temp->id;temp=temp->next);
   if (temp==NULL) return -1;
-  SET_ICONIFIED(temp,iconified);
+  if (flags!=-1) temp->flags=flags;
   return temp->count;
 }
 
-int UpdateItemGSFRFlags(List *list, ConfigWinPacket *cfgpacket)
+int UpdateItemFlagsDesk(List *list, long id, long flags, long desk)
 {
-  Item *temp;
-  for(temp=list->head;temp!=NULL && cfgpacket->w!=temp->id;temp=temp->next);
-  if (temp==NULL) return -1;
-  temp->flags = cfgpacket->flags;
-  return temp->count;
-}
-
-int UpdateItemIndexDesk(List *list, int i, long desk)
-{
-  Item *temp;
-  for(temp=list->head;temp!=NULL && temp->count!=i;temp=temp->next);
+Item *temp;
+  for(temp=list->head;temp!=NULL && id!=temp->id;temp=temp->next);
   if (temp==NULL) return -1;
+  if (flags!=-1) temp->flags=flags;
   temp->Desk=desk;
   return temp->count;
 }
 
-int UpdateNameItem(List *list, char *string, long id, int iconified)
-{
+int UpdateNameItem(List *list, char *string, long id, long flags) {
   Item *temp;
 
   for(temp=list->head;
       temp!=NULL && strcmp(temp->name,string) != 0;
       temp=temp->next);
   if (temp==NULL) return -1;
-  else {
-    if (id != -1) temp->id = id;
-    if (iconified != -1) SET_ICONIFIED(temp,iconified);
-    return temp->count;
-  }
-}
-
-int UpdateItemIndexGeometry(List *list, int i, rectangle *new_g)
-{
-  Item *temp;
-  for(temp=list->head;temp!=NULL && temp->count!=i;temp=temp->next);
-  if (temp==NULL) return -1;
-  temp->win_g = *new_g;
+  if (id != -1) temp->id = id;
+  if (flags != -1) temp->flags = flags;
   return temp->count;
 }
-
+  
 /******************************************************************************
   FreeItem - Frees allocated space for an Item
 ******************************************************************************/
@@ -211,7 +174,7 @@ int i;
     temp=list->head=list->head->next;
     i=temp2->count;
   } else {
-     for(temp=list->head,temp2=temp->next; temp2; temp2=temp2->next) {
+    for(temp=list->head,temp2=temp->next; temp2; temp2=temp2->next) {
       if (temp2->id == id)
         break;
       temp = temp2;
@@ -226,7 +189,6 @@ int i;
   FreeItem(temp2);
   list->count--;
   return i;
-/*    return i+1; */
 }
 
 /******************************************************************************
@@ -234,9 +196,8 @@ int i;
 ******************************************************************************/
 void FreeList(List *list)
 {
-  Item *temp,*temp2;
-  for(temp=list->head;temp!=NULL;)
-  {
+Item *temp,*temp2;
+  for(temp=list->head;temp!=NULL;) {
     temp2=temp;
     temp=temp->next;
     FreeItem(temp2);
@@ -245,18 +206,19 @@ void FreeList(List *list)
 }
 
 /******************************************************************************
-  PrintList - Print the list of item to stderr. (Debugging)
+  PrintList - Print the list of item on the console. (Debugging)
 ******************************************************************************/
 void PrintList(List *list)
 {
-  Item *temp;
-  fprintf(stderr,"%s List of Items:\n", Module);
-  fprintf(stderr,"   %10s %-15s %-15s %-15s %-15s Flgs\n","ID","Name","I-Name",
-		 "R-Name","R-Class");
-  fprintf(stderr,"   ---------- --------------- --------------- --------------- --------------- ----\n");
+Item *temp;
+  ConsoleMessage("List of Items:\n");
+  ConsoleMessage("   %10s %-15s %-15s %-15s %-15s Flgs\n","ID","Name","I-Name",
+    "R-Name","R-Class");
+  ConsoleMessage("   ---------- --------------- --------------- --------------- --------------- ----\n");
   for(temp=list->head;temp!=NULL;temp=temp->next) {
-    fprintf(stderr,"   %10ld %-15.15s\n",temp->id,
-		   (temp->name==NULL) ? "<null>" : temp->name);
+    ConsoleMessage("   %10ld %-15.15s %4d\n",temp->id,
+      (temp->name==NULL) ? "<null>" : temp->name,
+       temp->flags);
   }
 }
 
@@ -265,65 +227,46 @@ void PrintList(List *list)
 ******************************************************************************/
 char *ItemName(List *list, int n)
 {
-  Item *temp;
-  for(temp=list->head;temp!=NULL && temp->count!=n;temp=temp->next);
+Item *temp;
+  for(temp=list->head; temp!=NULL && temp->count!=n; temp=temp->next);
   if (temp==NULL) return NULL;
   return temp->name;
 }
 
 /******************************************************************************
-  IsItemIndexIconified - Say if an item is iconified
+  ItemFlags - Return the flags for an item
 ******************************************************************************/
-int IsItemIconified(List *list, long id)
+long ItemFlags(List *list, long id)
 {
-  Item *temp;
-  for(temp=list->head;temp!=NULL && temp->id!=id;temp=temp->next);
+Item *temp;
+  for(temp=list->head;temp!=NULL && id!=temp->id;temp=temp->next);
   if (temp==NULL) return -1;
-  return IS_ICONIFIED(temp);
+  else return temp->flags;
 }
 
 /******************************************************************************
-  IsItemIndexIconified - Say if an item of index i is iconified
+  ItemIndexFlags - Return the flags for an item of index i
 ******************************************************************************/
-int IsItemIndexIconified(List *list, int i)
+long ItemIndexFlags(List *list, int i)
 {
-  Item *temp;
-  for(temp=list->head;temp!=NULL && temp->count!=i;temp=temp->next);
+Item *temp;
+  for(temp=list->head; temp!=NULL && temp->count!=i; temp=temp->next);
   if (temp==NULL) return -1;
-  return IS_ICONIFIED(temp);
+  else return temp->flags;
 }
 
 /******************************************************************************
-  IsItemIndexSticky - Say if an item of index i is sticky
+  XorFlags - Exclusive of the flags with the specified value.
 ******************************************************************************/
-int IsItemIndexSticky(List *list, int i)
+long XorFlags(List *list, int n, long value)
 {
-  Item *temp;
-  for(temp=list->head;temp!=NULL && temp->count!=i;temp=temp->next);
+Item *temp;
+long ret;
+  for(temp=list->head; temp!=NULL && temp->count!=n; temp=temp->next);
   if (temp==NULL) return -1;
-  return (IS_STICKY(temp) || (IS_ICONIFIED(temp) && IS_ICON_STICKY(temp)));
-}
-
-/******************************************************************************
-  IsItemIndexSkipWindowList - Say if an item of index i is in the skip list
-******************************************************************************/
-int IsItemIndexSkipWindowList(List *list, int i)
-{
-  Item *temp;
-  for(temp=list->head;temp!=NULL && temp->count!=i;temp=temp->next);
-  if (temp==NULL) return -1;
-  return DO_SKIP_WINDOW_LIST(temp);
-}
-
-/******************************************************************************
-  IsItemIndexIconSuppressed - Say if an item has a no icon style
-******************************************************************************/
-int IsItemIndexIconSuppressed(List *list, int i)
-{
-  Item *temp;
-  for(temp=list->head;temp!=NULL && temp->count!=i;temp=temp->next);
-  if (temp==NULL) return -1;
-  return IS_ICON_SUPPRESSED(temp);
+  ret=temp->flags;
+  temp->flags^=value;
+  return ret;
 }
 
 /******************************************************************************
@@ -339,9 +282,9 @@ int ItemCount(List *list)
 ******************************************************************************/
 long ItemID(List *list, int n)
 {
-  Item *temp;
-  for(temp=list->head;temp!=NULL && temp->count!=n;temp=temp->next);
-  if (temp==NULL) return -1;
+Item *temp;
+  for (temp=list->head; temp!=NULL && temp->count!=n; temp=temp->next);
+  if (temp == NULL) return -1;
   return temp->id;
 }
 
@@ -350,13 +293,10 @@ long ItemID(List *list, int n)
 ******************************************************************************/
 void CopyItem(List *dest, List *source, int n)
 {
-  Item *temp;
-  ConfigWinPacket cfgpkt;
-
-  for(temp=source->head;temp!=NULL && temp->count!=n;temp=temp->next);
+Item *temp;
+  for(temp=source->head; temp!=NULL && temp->count!=n; temp=temp->next);
   if (temp==NULL) return;
-  memcpy(&cfgpkt.flags, &temp->flags, sizeof(cfgpkt.flags));
-  AddItem(dest, temp->id, &cfgpkt,temp->Desk,temp->count);
+  AddItem(dest,temp->id,temp->flags,temp->Desk,temp->count);
   UpdateItemName(dest,temp->id,temp->name);
   DeleteItem(source,temp->id);
 }
@@ -366,7 +306,7 @@ void CopyItem(List *dest, List *source, int n)
 ******************************************************************************/
 void UpdateItemPicture(List *list, int n, Picture *p)
 {
-  Item *temp;
+Item *temp;
 
   for (temp=list->head;temp && temp->count!=n;temp=temp->next);
   if (temp==NULL) return;
@@ -385,7 +325,7 @@ void UpdateItemPicture(List *list, int n, Picture *p)
 ******************************************************************************/
 int GetDeskNumber(List *list, int n, long *Desk)
 {
-  Item *temp;
+Item *temp;
 
   for (temp=list->head;temp && temp->count!=n;temp=temp->next);
   if (temp==NULL) return 0;
@@ -398,23 +338,9 @@ int GetDeskNumber(List *list, int n, long *Desk)
 ******************************************************************************/
 Picture *GetItemPicture(List *list, int n)
 {
-  Item *temp;
+Item *temp;
 
   for (temp=list->head;temp && temp->count!=n;temp=temp->next);
   if (temp==NULL) return 0;
   return &(temp->p);
 }
-
-/******************************************************************************
-  GetItemGeometry - returns a pointer to the internal geometry rectangle
-******************************************************************************/
-int GetItemGeometry(List *list, int n, rectangle **r)
-{
-  Item *temp;
-
-  for (temp=list->head;temp && temp->count!=n;temp=temp->next);
-  if (temp==NULL) return 0;
-  *r=&temp->win_g;
-  return 1;
-}
-
