@@ -1,4 +1,4 @@
-/* FvwmTaskBar Module for Fvwm.
+/* FvwmTaskBar Module for Fvwm. 
  *
  *  Copyright 1994,  Mike Finger (mfinger@mermaid.micro.umn.edu or
  *                               Mike_Finger@atk.com)
@@ -18,25 +18,11 @@
  * own risk. Permission to use this program for any purpose is given,
  * as long as the copyright is kept intact. */
 
-/* This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
-#ifndef _H_Mallocs
-#define _H_Mallocs
-
 /* Function Prototypes */
-void UpdateString(char **string, const char *value);
+char *safemalloc(int length);
+char *saferealloc(char *ptr, int length);
+void sleep_a_little(int n);
+void CopyString(char **dest, char *source);
+char *CatString2(char *a, char *b);
+void UpdateString(char **string,char *value);
 
-#endif
