@@ -1,14 +1,12 @@
-/* -*-c-*- */
-#include "config.h"
-#include <libs/fvwmlib.h>
+#include "../../include/fvwm/fvwmlib.h" 
+#include <FVWMconfig.h>
 
-/*
+/*************************************************************************
  *
  * Subroutine Prototypes
- *
- */
+ * 
+ *************************************************************************/
 extern void   CreateWindow(void);
-extern void   CreateVizWindow(void);
 extern Pixel  GetColor(char *name);
 extern void   nocolor(char *a, char *b);
 extern void   RedrawWindow(Window *win, int firstbutton, int newbutton, int num_rows, int num_columns);
@@ -22,13 +20,15 @@ extern void   ParseOptions(char *);
 extern char   *safemalloc(int length);
 extern void   change_window_name(char *str);
 extern int    My_XNextEvent(Display *dpy, XEvent *event);
-extern RETSIGTYPE DeadPipe(int nonsense);
-extern Bool   LoadIconFile(int button,int ico);
+extern void   DeadPipe(int nonsense);
+extern void   LoadIconFile(int button,int ico);
 extern void   CreateIconWindow(int button, Window *win);
-extern void   ConfigureIconWindow(int button,int row, int column, int colorset);
+extern void   ConfigureIconWindow(int button,int row, int column);
+extern void   GetBitmapFile(int button,int ico);
+extern int    GetXPMFile(int button,int ico);
+extern int    GetXPMData(int button, char **data);
 extern int    GetXPMGradient(int button, int from[3], int to[3], int maxcols,
 		   int type);
-extern void   GetXPMColorset(int button, int colorset);
 extern int    GetSolidXPM(int button, Pixel pixel);
 extern Bool Pushed;
 extern Bool ForceSize;
@@ -45,10 +45,11 @@ void RedrawUnpushed(Window *win, int i, int j);
 void RedrawUnpushedOutline(Window *win, int i,int j);
 void RedrawPushedOutline(Window *win, int i, int j);
 void CreateShadowGC(void);
-extern Display *dpy;                    /* which display are we talking to */
+extern Display *dpy;			/* which display are we talking to */
 extern Window Root;
 extern Window main_win;
 extern int screen;
+extern long d_depth;
 extern Pixel back_pix, fore_pix;
 extern GC  NormalGC, HiReliefGC, HiInnerGC;
 extern GC  MaskGC;
@@ -62,7 +63,7 @@ extern XFontStruct *font;
 #define BUTTON_ARRAY_LN 102
 #define FOLDER_ARRAY_LN 10
 
-#define ICON_WIN_WIDTH  48
+#define ICON_WIN_WIDTH	48
 #define ICON_WIN_HEIGHT 48
 
 #define ISMAPPED 0
@@ -70,9 +71,9 @@ extern XFontStruct *font;
 
 typedef struct icon_info {
     char *file;
-    int w, h;
-    Pixmap icon, mask, alpha;
-    int depth;
+    short w, h;
+    Pixmap icon, mask;
+    char depth;    
 } icon_info;
 
 struct button_info
@@ -82,7 +83,7 @@ struct button_info
   int iconno;
   icon_info icons[MAX_OVERLAY];
 
-  Pixmap completeIcon;          /* icon with background */
+  Pixmap completeIcon;		/* icon with background */
   Window IconWin;
   Window *parent;
   XSizeHints hints;
@@ -94,7 +95,7 @@ struct button_info
   int folder;
 #ifdef ENABLE_DND
   char *drop_action;
-#endif
+#endif    
 };
 
 struct folder_info
@@ -111,4 +112,15 @@ struct folder_info
 extern struct button_info Buttons[MAX_BUTTONS+2];
 extern struct folder_info Folders[FOLDER_ARRAY_LN];
 
-extern char *imagePath;
+extern char *iconPath;
+extern char *pixmapPath;
+
+#ifdef BROKEN_SUN_HEADERS
+#include "../../afterstep/sun_headers.h"
+#endif
+
+#ifdef NEEDS_ALPHA_HEADER
+#include "../../afterstep/alpha_header.h"
+#endif /* NEEDS_ALPHA_HEADER */
+
+
