@@ -1,41 +1,22 @@
-/* This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
 /*
  * Generic graphics and misc. utilities
- *
+ * 
  */
 
 #include <X11/Xlib.h>
 #include <stdlib.h>
-extern Window main_win;
-#include "libs/fvwmlib.h"
-#include "libs/PictureBase.h"
-#include "libs/PictureUtils.h"
 
-/* Masks to apply to color components when allocating colors
+/* Masks to apply to color components when allocating colors 
  * you may want to set them to 0xffff if your display supports 16bpp+
  */
-#define RED_MASK        0xff00
-#define GREEN_MASK      0xff00
-#define BLUE_MASK       0xff00
+#define RED_MASK	0xff00
+#define GREEN_MASK	0xff00
+#define BLUE_MASK	0xff00
 /*
- ***********************************************************************
- * Allocates colors and fill a pixel value array. Color values are
+ *********************************************************************** 
+ * Allocates colors and fill a pixel value array. Color values are 
  * truncated with RED_MASK, GREEN_MASK and BLUE_MASK
- *
+ * 
  * from,to are the primary colors to use
  * maxcols is the number of colors
  * colors is the array of pixel values
@@ -45,7 +26,7 @@ extern Window main_win;
  * incr - 0 if gradient is light to dark, 1 if dark to light
  ***********************************************************************
  */
-int MakeColors(Display *dpy, Drawable d, int from[3], int to[3], int maxcols,
+int MakeColors(Display *dpy, Drawable d, int from[3], int to[3], int maxcols, 
 	       unsigned long *colors, unsigned long *dark,
 	       unsigned long *light, int dr, int dg, int db,
 	       int alloc_relief, int incr)
@@ -58,7 +39,7 @@ int MakeColors(Display *dpy, Drawable d, int from[3], int to[3], int maxcols,
 
     sr = (float)dr / (float)maxcols;
     sg = (float)dg / (float)maxcols;
-    sb = (float)db / (float)maxcols;
+    sb = (float)db / (float)maxcols;    
     rv = (float)from[0];
     gv = (float)from[1];
     bv = (float)from[2];
@@ -67,7 +48,7 @@ int MakeColors(Display *dpy, Drawable d, int from[3], int to[3], int maxcols,
     color.green = 0;
     color.blue = 0;
     for(i = 0; i < maxcols; i++) {
-	/* color allocation saver */
+	/* color allocation saver */	
 	red = ((short)rv) & RED_MASK;
 	green = ((short)gv) & GREEN_MASK;
 	blue = ((short)bv) & BLUE_MASK;
@@ -75,17 +56,18 @@ int MakeColors(Display *dpy, Drawable d, int from[3], int to[3], int maxcols,
 	    color.red = red;
 	    color.green = green;
 	    color.blue = blue;
-	    if (PictureAllocColor(dpy, Pcmap, &color, True)==0) {
-		return 0;
+	    if (XAllocColor(dpy, DefaultColormap(dpy, DefaultScreen(dpy)),
+			&color)==0) {
+	        return 0;
 	    }
 	}
 	colors[i] = color.pixel;
 	rv += sr;
 	gv += sg;
 	bv += sb;
-	if ((rv > 65535.0) || (rv < 0.0)) rv -= sr;
-	if ((gv > 65535.0) || (gv < 0.0)) gv -= sg;
-	if ((bv > 65535.0) || (bv < 0.0)) bv -= sb;
+	rv = ((rv > 65535.0) || (rv < 0.0)) ? rv -= sr : rv;
+	gv = ((gv > 65535.0) || (gv < 0.0)) ? gv -= sg : gv;
+	bv = ((bv > 65535.0) || (bv < 0.0)) ? bv -= sb : bv;
     }
     /* allocate 2 colors for the bevel */
     if (alloc_relief) {
@@ -100,20 +82,20 @@ int MakeColors(Display *dpy, Drawable d, int from[3], int to[3], int maxcols,
 	}
 	color.red = (unsigned short)(rv<0?0:rv);
     color.green = (unsigned short)(gv<0?0:gv);
-	color.blue = (unsigned short)(bv<0?0:bv);
-	if (PictureAllocColor(dpy, Pcmap, &color, True))
+	color.blue = (unsigned short)(bv<0?0:bv);		
+	if (XAllocColor(dpy, DefaultColormap(dpy, DefaultScreen(dpy)),&color))
 	  *dark = color.pixel;
 	else
 	  *dark = colors[incr ? 0 : maxcols-1];
-
+	
 	if (incr) {
 	    float avg;
-	    avg = (float)(to[0]+to[1]+to[2])/3;
+	    avg = (float)(to[0]+to[1]+to[2])/3;	
 	    rv = avg + (float)(to[0]/2);
 	    gv = avg + (float)(to[1]/2);
 	    bv = avg + (float)(to[2]/2);
 	} else {
-	    float avg;
+            float avg; 	
 	    avg = (float)(from[0]+from[1]+from[2])/3;
 	    rv = avg + (float)(from[0]/2);
 	    gv = avg + (float)(from[1]/2);
@@ -122,57 +104,58 @@ int MakeColors(Display *dpy, Drawable d, int from[3], int to[3], int maxcols,
 	color.red = (unsigned short)(rv>65535.0 ? 65535.0:rv);
     color.green = (unsigned short)(gv>65535.0 ? 65535.0:gv);
 	color.blue = (unsigned short)(bv>65535.0 ? 65535.0:bv);
-	if (PictureAllocColor(dpy, Pcmap, &color, True))
+	if (XAllocColor(dpy, DefaultColormap(dpy, DefaultScreen(dpy)), 
+			&color))
 	  *light = color.pixel;
 	else
 	  *light = colors[incr ? maxcols-1 : 0];
     } else {
 	*light = colors[incr ? maxcols-1 : 0];
-	*dark = colors[incr ? 0 : maxcols-1];
-    }
+	*dark = colors[incr ? 0 : maxcols-1];   
+    }    
     return 1;
 }
 
 
 /*
  ************************************************************************
- *
+ * 
  * Draws a texture similar to Wharf's button background
  *
  * from: r,g,b values of top left color
  * to: r,g,b values of bottom right color
  * relief: relief to add to the borders. 0=flat, >0 raised, <0 sunken
  * maxcols: # of max colors to use
- *
+ * 
  * Aborts and returns 0 on error
  ************************************************************************
  */
 
-int DrawDegradeRelief(Display *dpy, Drawable d, int x, int y, int w, int h,
+int DrawDegradeRelief(Display *dpy, Drawable d, int x, int y, int w, int h, 
 		       int from[3], int to[3], int relief, int maxcols)
 {
-    int         i = 0,j,k;
-    int         dr, dg, db;  /* delta */
-    int         dmax, dmax2;
-    GC          gc, gc2;
-    XGCValues   gcv;
-    int         px, py, pd;
+    int		i,j,k;
+    int		dr, dg, db;  /* delta */
+    int		dmax, dmax2;
+    GC		gc, gc2;
+    XGCValues	gcv;
+    int		px, py, pd;
     unsigned long lightcolor, darkcolor;
-    int         alloc_relief;
+    int 	alloc_relief;
     unsigned long  *colors;
-    float       c1,s1;
+    float	c1,s1;
 
     if (w <= 0 || h <= 0)
       return 0;
 
     gcv.foreground = 1;
-    gc = fvwmlib_XCreateGC(dpy, d, GCForeground, &gcv);
-    gc2 = fvwmlib_XCreateGC(dpy, d, GCForeground, &gcv);
+    gc = XCreateGC(dpy, d, GCForeground, &gcv);
+    gc2 = XCreateGC(dpy, d, GCForeground, &gcv);
 
     dr = to[0] - from[0];
     dg = to[1] - from[1];
     db = to[2] - from[2];
-
+    
     dmax = abs(dr);
     dmax2 = dr;
     if (dmax < abs(dg)) {
@@ -182,7 +165,7 @@ int DrawDegradeRelief(Display *dpy, Drawable d, int x, int y, int w, int h,
     if (dmax < abs(db)) {
 	dmax = abs(db);
 	dmax2 = db;
-    }
+    }    
     /* if colors from and to are the same, force to one color */
     if (dmax==0)  dmax=1;
 
@@ -195,17 +178,17 @@ int DrawDegradeRelief(Display *dpy, Drawable d, int x, int y, int w, int h,
 	}
     } else
       alloc_relief = 0;
-
+    
     if (dmax < maxcols) {
 	maxcols = dmax; /* we need less colors than we expected */
     }
-
+    
     colors = malloc(sizeof(unsigned long)*maxcols);
     /* alloc colors */
     if (!MakeColors(dpy, d, from, to, maxcols, colors, &darkcolor, &lightcolor,
 	       dr, dg, db, alloc_relief, dmax2>0))
       return 0;
-
+    
     /* display it */
     s1 = (float)(maxcols)/((float)w*2.0);
     pd = relief==0 ? 0 : 1;
@@ -234,7 +217,7 @@ int DrawDegradeRelief(Display *dpy, Drawable d, int x, int y, int w, int h,
 	    XSetForeground(dpy, gc2, darkcolor);
 	} else {
 	    XSetForeground(dpy, gc, darkcolor);
-	    XSetForeground(dpy, gc2, lightcolor);
+	    XSetForeground(dpy, gc2, lightcolor);	    
 	}
 	XDrawLine(dpy, d, gc, x, y, x, y+h-1);
 	XDrawLine(dpy, d, gc, x, y, x+w-1, y);
@@ -250,7 +233,7 @@ int DrawDegradeRelief(Display *dpy, Drawable d, int x, int y, int w, int h,
 
 /*
  ************************************************************************
- *
+ * 
  * Draws a horizontal gradient
  *
  * from: r,g,b values of top color
@@ -258,35 +241,35 @@ int DrawDegradeRelief(Display *dpy, Drawable d, int x, int y, int w, int h,
  * relief: relief to add to the borders. 0=flat, >0 raised, <0 sunken
  * maxcols: max colors to use
  * type: gradient type. 0 for one-way, != 0 for cilindrical
- *
+ * 
  * aborts and returns 0 on error.
  ************************************************************************
  */
-int DrawHGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
+int DrawHGradient(Display *dpy, Drawable d, int x, int y, int w, int h, 
 		       int from[3], int to[3], int relief, int maxcols,
 		       int type)
 {
-    int         i,j;
-    XGCValues   gcv;
-    GC          gc, gc2;
-    int         dr,dg,db;
-    float       s,c;
-    int         dmax;
+    int		i,j;
+    XGCValues	gcv;
+    GC		gc, gc2;
+    int		dr,dg,db;
+    float	s,c;
+    int 	dmax;
     unsigned long  *colors, lightcolor, darkcolor;
-    int         py,pd;
-    int         alloc_relief;
-
+    int 	py,pd;
+    int 	alloc_relief;
+    
     if (w <= 1 || h <= 1)
       return 0;
 
     gcv.foreground = 1;
-    gc = fvwmlib_XCreateGC(dpy, d, GCForeground, &gcv);
-    gc2 = fvwmlib_XCreateGC(dpy, d, GCForeground, &gcv);
-
+    gc = XCreateGC(dpy, d, GCForeground, &gcv);
+    gc2 = XCreateGC(dpy, d, GCForeground, &gcv);
+    
     dr = to[0] - from[0];
     dg = to[1] - from[1];
     db = to[2] - from[2];
-
+    
     dmax = dr;
     if (abs(dmax) < abs(dg)) {
 	dmax = dg;
@@ -303,7 +286,7 @@ int DrawHGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
 	}
     } else
       alloc_relief=0;
-
+    
     if (type) {
 	if (h/2 < maxcols) {
 	    maxcols = h/2; /* we need less colors than we expected */
@@ -322,13 +305,13 @@ int DrawHGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
     if (type) {
 	s = ((float)maxcols*2)/(float)h;
     } else {
-	s = (float)maxcols/(float)h;
-    }
+	s = (float)maxcols/(float)h;	
+    }    
     pd = relief==0 ? 0 : 1;
     c=0;
     j=-1;
     if (type==0) { /* one-way */
-	for(py = pd; py < h-pd; py++) {
+	for(py = pd; py < h-pd; py++) {	
 	    i=(int)c;
 	    if (i>=maxcols) i=maxcols-1;
 	    if (j != i) {
@@ -339,7 +322,7 @@ int DrawHGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
 	    c += s;
 	}
     } else { /* cylindrical */
-	for(py = pd; py < h-pd; py++) {
+	for(py = pd; py < h-pd; py++) {	
 	    i=(int)c;
 	    if (i>=maxcols) i=maxcols-1;
 	    if (j != i) {
@@ -350,7 +333,7 @@ int DrawHGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
 	    if (py == h/2) s = -s;
 	    c += s;
 	}
-    }
+    }    
     /* draw borders */
     if (relief != 0) {
 	if (relief>0) {
@@ -358,7 +341,7 @@ int DrawHGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
 	    XSetForeground(dpy, gc2, darkcolor);
 	} else {
 	    XSetForeground(dpy, gc, darkcolor);
-	    XSetForeground(dpy, gc2, lightcolor);
+	    XSetForeground(dpy, gc2, lightcolor);	    
 	}
 	XDrawLine(dpy, d, gc, x, y, x, y+h-1);
 	XDrawLine(dpy, d, gc, x, y, x+w-1, y);
@@ -374,7 +357,7 @@ int DrawHGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
 
 /*
  ************************************************************************
- *
+ * 
  * Draws a vertical gradient
  *
  * from: r,g,b values of left color
@@ -382,35 +365,35 @@ int DrawHGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
  * relief: relief to add to the borders. 0=flat, >0 raised, <0 sunken
  * maxcols: max colors to use
  * type: gradient type. 0 for one-way, != 0 for cilindrical
- *
+ * 
  * aborts and returns 0 on error.
  ************************************************************************
  */
-int DrawVGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
+int DrawVGradient(Display *dpy, Drawable d, int x, int y, int w, int h, 
 		       int from[3], int to[3], int relief, int maxcols,
 		       int type)
 {
-    int         i,j;
-    XGCValues   gcv;
-    GC          gc, gc2;
-    int         dr,dg,db;
-    float       s,c;
-    int         dmax;
+    int		i,j;
+    XGCValues	gcv;
+    GC		gc, gc2;
+    int		dr,dg,db;
+    float	s,c;
+    int 	dmax;
     unsigned long  *colors, lightcolor, darkcolor;
-    int         px,pd;
-    int         alloc_relief;
-
+    int 	px,pd;
+    int 	alloc_relief;
+    
     if (w <= 1 || h <= 1)
       return 0;
 
     gcv.foreground = 1;
-    gc = fvwmlib_XCreateGC(dpy, d, GCForeground, &gcv);
-    gc2 = fvwmlib_XCreateGC(dpy, d, GCForeground, &gcv);
-
+    gc = XCreateGC(dpy, d, GCForeground, &gcv);
+    gc2 = XCreateGC(dpy, d, GCForeground, &gcv);
+    
     dr = to[0] - from[0];
     dg = to[1] - from[1];
     db = to[2] - from[2];
-
+    
     dmax = dr;
     if (abs(dmax) < abs(dg)) {
 	dmax = dg;
@@ -427,7 +410,7 @@ int DrawVGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
 	}
     } else
       alloc_relief=0;
-
+    
     if (type) {
 	if (w/2 < maxcols) {
 	    maxcols = w/2; /* we need less colors than we expected */
@@ -446,13 +429,13 @@ int DrawVGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
     if (type) {
 	s = ((float)maxcols*2)/(float)w;
     } else {
-	s = (float)maxcols/(float)w;
-    }
+	s = (float)maxcols/(float)w;	
+    }    
     pd = relief==0 ? 0 : 1;
     c=0;
     j=-1;
     if (type==0) { /* one-way */
-	for(px = pd; px < w-pd; px++) {
+	for(px = pd; px < w-pd; px++) {	
 	    i=(int)c;
 	    if (i>=maxcols) i=maxcols-1;
 	    if (j != i) {
@@ -463,7 +446,7 @@ int DrawVGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
 	    c += s;
 	}
     } else { /* cylindrical */
-	for(px = pd; px < w-pd; px++) {
+	for(px = pd; px < w-pd; px++) {	
 	    i=(int)c;
 	    if (i>=maxcols) i=maxcols-1;
 	    if (j != i) {
@@ -482,7 +465,7 @@ int DrawVGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
 	    XSetForeground(dpy, gc2, darkcolor);
 	} else {
 	    XSetForeground(dpy, gc, darkcolor);
-	    XSetForeground(dpy, gc2, lightcolor);
+	    XSetForeground(dpy, gc2, lightcolor);	    
 	}
 	XDrawLine(dpy, d, gc, x, y, x, y+h-1);
 	XDrawLine(dpy, d, gc, x, y, x+w-1, y);
@@ -497,9 +480,9 @@ int DrawVGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
 
 
 /************************************************************************
- *
+ * 
  * Draws text with a texture
- *
+ * 
  * d - target drawable
  * font - font to draw text
  * x,y - position of text
@@ -509,28 +492,28 @@ int DrawVGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
  ************************************************************************/
 void DrawTexturedText(Display *dpy, Drawable d, XFontStruct *font,
 		      int x, int y, Pixmap gradient, char *text, int chars)
-
+		      
 {
     Pixmap mask;
     int w,h;
     GC gc;
     XGCValues gcv;
-
+    
     /* make the mask pixmap */
     w = XTextWidth(font,text,chars);
     h = font->ascent+font->descent;
-    mask=XCreatePixmap(dpy,main_win,w+1,h+1,1);
+    mask=XCreatePixmap(dpy,DefaultRootWindow(dpy),w+1,h+1,1);
 	gcv.foreground = 0;
 	gcv.function = GXcopy;
-    gcv.font = font->fid;
-	gc = fvwmlib_XCreateGC(dpy,mask,GCFunction|GCForeground|GCFont,&gcv);
+    gcv.font = font->fid;	
+	gc = XCreateGC(dpy,mask,GCFunction|GCForeground|GCFont,&gcv);
     XFillRectangle(dpy,mask,gc,0,0,w,h);
 	XSetForeground(dpy,gc,1);
     XDrawString(dpy,mask,gc,0,font->ascent,text,chars);
 	XFreeGC(dpy,gc);
 	/* draw the texture */
 	gcv.function=GXcopy;
-	gc = fvwmlib_XCreateGC(dpy,d,GCFunction,&gcv);
+	gc = XCreateGC(dpy,d,GCFunction,&gcv);
     XSetClipOrigin(dpy,gc,x,y);
     XSetClipMask(dpy,gc,mask);
     XCopyArea(dpy,gradient,d,gc,0,0,w,h,x,y);
@@ -546,12 +529,14 @@ int MakeShadowColors(Display *dpy, int from[3], int to[3],
 {
     float rv, gv, bv;
     XColor color;
-    int incr;
-    int dr,dg,db,dmax;
+    int i;
+	int incr;
+	int dr,dg,db,dmax;
+
     dr = to[0] - from[0];
     dg = to[1] - from[1];
     db = to[2] - from[2];
-
+    
     dmax = dr;
     if (abs(dmax) < abs(dg)) {
 		dmax = dg;
@@ -560,7 +545,7 @@ int MakeShadowColors(Display *dpy, int from[3], int to[3],
 		dmax = db;
     }
 	incr=(dmax>0);
-    /* allocate 2 colors for the bevel */
+    /* allocate 2 colors for the bevel */    
 	if (incr) {
 	    rv = (float)from[0] * 0.8;
 	    gv = (float)from[1] * 0.8;
@@ -571,30 +556,31 @@ int MakeShadowColors(Display *dpy, int from[3], int to[3],
 	    bv = (float)to[2] * 0.8;
 	}
 	color.red = (short)(rv<0?0:rv);
-	color.green = (short)(gv<0?0:gv);
+    color.green = (short)(gv<0?0:gv);
 	color.blue = (short)(bv<0?0:bv);
-	if (PictureAllocColor(dpy, Pcmap ,&color, True))
+	if (XAllocColor(dpy, DefaultColormap(dpy, DefaultScreen(dpy)),&color))
 	  *dark = color.pixel;
 	else
 	  return 0;
-
+	
 	if (incr) {
 	    float avg;
-	    avg = (float)(to[0]+to[1]+to[2])/3;
+	    avg = (float)(to[0]+to[1]+to[2])/3;	
 	    rv = avg + (float)(to[0]/2);
 	    gv = avg + (float)(to[1]/2);
 	    bv = avg + (float)(to[2]/2);
 	} else {
-	float avg;
+        float avg; 	
 	    avg = (float)(from[0]+from[1]+from[2])/3;
 	    rv = avg + (float)(from[0]/2);
 	    gv = avg + (float)(from[1]/2);
 	    bv = avg + (float)(from[2]/2);
 	}
 	color.red = (unsigned short)(rv>65535.0 ? 65535.0:rv);
-	color.green = (unsigned short)(gv>65535.0 ? 65535.0:gv);
-	color.blue = (unsigned short)(bv>65535.0 ? 65535.0:bv);
-	if (PictureAllocColor(dpy, Pcmap, &color, True))
+    color.green = (unsigned short)(gv>65535.0 ? 65535.0:gv);
+	color.blue = (unsigned short)(bv>65535.0 ? 65535.0:bv);	
+	if (XAllocColor(dpy, DefaultColormap(dpy, DefaultScreen(dpy)),
+					&color))
 	  *light = color.pixel;
 	else
 	  return 0;
